vars library

Properties

blocks Map<String, List<int>>
Map that can contain blocks informations, like start, end and inforamtion about indentation
getter/setter pair
commands Map<String, Function>
List of commands that available for calling
final
context Map<String, dynamic>
Context for expression parsing
getter/setter pair
cur int
Current line
getter/setter pair
indent int
Current indentation
getter/setter pair
input List<String>?
List of input. Has values if they were specified before code running
getter/setter pair
lines List<Map<String, dynamic>>
Contains lines of code. Has values after running code
getter/setter pair
output List<String>
List of all outputs of lprint
getter/setter pair
printToTerminal bool
If it is true, lprint won't print anything to terminal
getter/setter pair
runFilePath String?
Path to current file
getter/setter pair